[Asterisk-code-review] channels: Spelling fixes (asterisk[19])

Friendly Automation asteriskteam at digium.com
Mon Nov 15 23:17:53 CST 2021


Friendly Automation has submitted this change. ( https://gerrit.asterisk.org/c/asterisk/+/17415 )

Change subject: channels: Spelling fixes
......................................................................

channels: Spelling fixes

Correct typos of the following word families:

appease
permanently
overriding
residue
silliness
extension
channels
globally
reference
japanese
group
coordinate
registry
information
inconvenience
attempts
cadence
payloads
presence
provisioning
mimics
behavior
width
natively
syslabel
not owning
unquelch
mostly
constants
interesting
active
unequipped
brodmann
commanding
backlogged
without
bitstream
firmware
maintain
exclusive
practically
structs
appearance
range
retransmission
indication
provisional
associating
always
whether
cyrillic
distinctive
components
reinitialized
initialized
capability
switches
occurring
happened
outbound

ASTERISK-29714

Change-Id: Ife52ee89cd2170b684fa651ca72b1cb911a57339
---
M channels/chan_dahdi.c
M channels/chan_iax2.c
M channels/chan_mgcp.c
M channels/chan_motif.c
M channels/chan_rtp.c
M channels/chan_sip.c
M channels/chan_skinny.c
M channels/chan_unistim.c
M channels/console_gui.c
M channels/console_video.c
M channels/dahdi/bridge_native_dahdi.c
M channels/iax2/include/astobj.h
M channels/iax2/include/firmware.h
M channels/iax2/parser.c
M channels/sig_analog.c
M channels/sig_pri.c
M channels/sig_pri.h
M channels/sig_ss7.c
M channels/sig_ss7.h
M channels/sip/include/config_parser.h
M channels/sip/include/reqresp_parser.h
M channels/sip/include/sip.h
M channels/sip/reqresp_parser.c
M channels/vcodecs.c
24 files changed, 75 insertions(+), 75 deletions(-)

Approvals:
  George Joseph: Looks good to me, approved
  Friendly Automation: Approved for Submit



diff --git a/channels/chan_iax2.c b/channels/chan_iax2.c
index 91aa1f7..a0da22d 100644
--- a/channels/chan_iax2.c
+++ b/channels/chan_iax2.c
@@ -1166,7 +1166,7 @@
 /*!
  *  * \brief Another container of iax2_pvt structures
  *
- *  Active IAX2 pvt stucts used during transfering a call are stored here.
+ *  Active IAX2 pvt structs used during transfering a call are stored here.
  */
 static struct ao2_container *iax_transfercallno_pvts;
 
@@ -2690,7 +2690,7 @@
 	 * Container locked here since peercnt may be unlinked from
 	 * list.  If left unlocked, peercnt_add could try and grab this
 	 * entry from the table and modify it at the "same time" this
-	 * thread attemps to unlink it.
+	 * thread attempts to unlink it.
 	 */
 	ao2_lock(peercnts);
 	peercnt->cur--;
@@ -4581,7 +4581,7 @@
 	ast_update_realtime("iaxpeers", "name", peername,
 		"ipaddr", ast_sockaddr_isnull(sockaddr) ? "" : ast_sockaddr_stringify_addr(sockaddr),
 		"port", ast_sockaddr_isnull(sockaddr) ? "" : port,
-		"regseconds", regseconds, syslabel, sysname, SENTINEL); /* note syslable can be NULL */
+		"regseconds", regseconds, syslabel, sysname, SENTINEL); /* note syslabel can be NULL */
 }
 
 struct create_addr_info {
@@ -8720,7 +8720,7 @@
 		remove_by_peercallno(pvt);
 	}
 	pvt->peercallno = peercallno;
-	/*this is where the transfering call swiches hash tables */
+	/*this is where the transfering call switches hash tables */
 	store_by_peercallno(pvt);
 	pvt->transferring = TRANSFER_NONE;
 	pvt->svoiceformat = -1;
@@ -9309,7 +9309,7 @@
 			return send_command(iaxs[callno], AST_FRAME_IAX, IAX_COMMAND_REGREQ, 0, ied.buf, ied.pos, -1);
 		} else
 			return -1;
-		ast_log(LOG_WARNING, "Registry acknowledge on unknown registery '%s'\n", peer);
+		ast_log(LOG_WARNING, "Registry acknowledge on unknown registry '%s'\n", peer);
 	} else
 		ast_log(LOG_NOTICE, "Can't reregister without a reg\n");
 	return -1;
@@ -9532,7 +9532,7 @@
 			res = send_trunk(tpeer, &now);
 			trunk_timed++;
 			if (iaxtrunkdebug) {
-				ast_verbose(" - Trunk peer (%s) has %d call chunk%s in transit, %u bytes backloged and has hit a high water mark of %u bytes\n",
+				ast_verbose(" - Trunk peer (%s) has %d call chunk%s in transit, %u bytes backlogged and has hit a high water mark of %u bytes\n",
 							ast_sockaddr_stringify(&tpeer->addr),
 							res,
 							(res != 1) ? "s" : "",
diff --git a/channels/chan_mgcp.c b/channels/chan_mgcp.c
index ebb50e6..3a0c7b3 100644
--- a/channels/chan_mgcp.c
+++ b/channels/chan_mgcp.c
@@ -335,7 +335,7 @@
 	char name[80];
 	struct mgcp_subchannel *sub;		/*!< Pointer to our current connection, channel and stuff */
 	char accountcode[AST_MAX_ACCOUNT_CODE];
-	char exten[AST_MAX_EXTENSION];		/*!< Extention where to start */
+	char exten[AST_MAX_EXTENSION];		/*!< Extension where to start */
 	char context[AST_MAX_EXTENSION];
 	char language[MAX_LANGUAGE];
 	char cid_num[AST_MAX_EXTENSION];	/*!< Caller*ID number */
@@ -3089,7 +3089,7 @@
 			timeout = firstdigittimeout;
 		} else if (!strcmp(p->dtmf_buf, pickupexten)) {
 			/* Scan all channels and see if any there
-			 * ringing channqels with that have call groups
+			 * ringing channels with that have call groups
 			 * that equal this channels pickup group
 			 */
 			if (ast_pickup_call(chan)) {
@@ -3445,7 +3445,7 @@
 			sub->cxmode = MGCP_CX_SENDRECV;
 
 			if (p) {
-			  /* When the endpoint have a Off hook transition we allways
+			  /* When the endpoint have a Off hook transition we always
 			     starts without any previous dtmfs */
 			  memset(p->dtmf_buf, 0, sizeof(p->dtmf_buf));
 			}
@@ -3534,7 +3534,7 @@
 			}
 			*/
 			if (p->transfer && (sub->owner && sub->next->owner) && ((!sub->outgoing) || (!sub->next->outgoing))) {
-				/* We're allowed to transfer, we have two avtive calls and */
+				/* We're allowed to transfer, we have two active calls and */
 				/* we made at least one of the calls.  Let's try and transfer */
 				ast_mutex_lock(&p->sub->next->lock);
 				res = attempt_transfer(p, sub);
diff --git a/channels/chan_motif.c b/channels/chan_motif.c
index 9315134..8da2d16 100644
--- a/channels/chan_motif.c
+++ b/channels/chan_motif.c
@@ -209,7 +209,7 @@
 					<synopsis>Maximum number of ICE candidates to offer</synopsis>
 				</configOption>
 				<configOption name="maxpayloads">
-					<synopsis>Maximum number of pyaloads to offer</synopsis>
+					<synopsis>Maximum number of payloads to offer</synopsis>
 				</configOption>
 			</configObject>
 		</configFile>
@@ -2310,7 +2310,7 @@
 				rtp = session->vrtp;
 			}
 		} else {
-			/* Google-V1 has no concept of assocating things like the above does, so since we only support audio over it assume they want audio */
+			/* Google-V1 has no concept of associating things like the above does, so since we only support audio over it assume they want audio */
 			rtp = session->rtp;
 		}
 
diff --git a/channels/chan_rtp.c b/channels/chan_rtp.c
index d8f7324..087ddae 100644
--- a/channels/chan_rtp.c
+++ b/channels/chan_rtp.c
@@ -20,7 +20,7 @@
 /*! \file
  *
  * \author Joshua Colp <jcolp at digium.com>
- * \author Andreas 'MacBrody' Broadmann <andreas.brodmann at gmail.com>
+ * \author Andreas 'MacBrody' Brodmann <andreas.brodmann at gmail.com>
  *
  * \brief RTP (Multicast and Unicast) Media Channel
  *
diff --git a/channels/chan_sip.c b/channels/chan_sip.c
index 23b8fa6..6757f51 100644
--- a/channels/chan_sip.c
+++ b/channels/chan_sip.c
@@ -794,7 +794,7 @@
 static char default_language[MAX_LANGUAGE];      /*!< Default language setting for new channels */
 static char default_callerid[AST_MAX_EXTENSION]; /*!< Default caller ID for sip messages */
 static char default_mwi_from[80];                /*!< Default caller ID for MWI updates */
-static char default_fromdomain[AST_MAX_EXTENSION]; /*!< Default domain on outound messages */
+static char default_fromdomain[AST_MAX_EXTENSION]; /*!< Default domain on outbound messages */
 static int default_fromdomainport;                 /*!< Default domain port on outbound messages */
 static char default_notifymime[AST_MAX_EXTENSION]; /*!< Default MIME media type for MWI notify messages */
 static char default_vmexten[AST_MAX_EXTENSION];    /*!< Default From Username on MWI updates */
@@ -9656,7 +9656,7 @@
 				Without a dialog we can't retransmit and handle ACKs and all that, but at least
 				send an error message.
 
-				Sorry, we apologize for the inconvienience
+				Sorry, we apologize for the inconvenience
 			*/
 			transmit_response_using_temp(callid, addr, 1, intended_method, req, "500 Server internal error");
 			ast_debug(4, "Failed allocating SIP dialog, sending 500 Server internal error and giving up\n");
@@ -12828,7 +12828,7 @@
 }
 
 /*!
-  \brief Choose realm based on From header and then To header or use globaly configured realm.
+  \brief Choose realm based on From header and then To header or use globally configured realm.
   Realm from From/To header should be listed among served domains in config file: domain=...
 */
 static void get_realm(struct sip_pvt *p, const struct sip_request *req)
@@ -13622,7 +13622,7 @@
 
 		if (doing_directmedia) {
 			ast_format_cap_get_compatible(p->jointcaps, p->redircaps, tmpcap);
-			ast_debug(1, "** Our native-bridge filtered capablity: %s\n", ast_format_cap_get_names(tmpcap, &codec_buf));
+			ast_debug(1, "** Our native-bridge filtered capability: %s\n", ast_format_cap_get_names(tmpcap, &codec_buf));
 		} else {
 			ast_format_cap_append_from_cap(tmpcap, p->jointcaps, AST_MEDIA_TYPE_UNKNOWN);
 		}
@@ -25819,7 +25819,7 @@
 		case 200:	/* OK: The new call is up, hangup this call */
 			/* Hangup the call that we are replacing */
 			break;
-		case 301: /* Moved permenantly */
+		case 301: /* Moved permanently */
 		case 302: /* Moved temporarily */
 			/* Do we get the header in the packet in this case? */
 			success = FALSE;
@@ -35359,7 +35359,7 @@
 			info->summary = "SIP TCP message fragmentation test";
 			info->description =
 				"Tests reception of different TCP messages that have been fragmented or"
-				"run together. This test mimicks the code that TCP reception uses.";
+				"run together. This test mimics the code that TCP reception uses.";
 			return AST_TEST_NOT_RUN;
 		case TEST_EXECUTE:
 			break;
diff --git a/channels/chan_skinny.c b/channels/chan_skinny.c
index 2966ea2..788d3ec 100644
--- a/channels/chan_skinny.c
+++ b/channels/chan_skinny.c
@@ -1366,7 +1366,7 @@
 static int matchdigittimeout = 3000;
 
 /*!
- * To apease the stupid compiler option on ast_sched_del()
+ * To appease the stupid compiler option on ast_sched_del()
  * since we don't care about the return value.
  */
 static int not_used;
@@ -2794,7 +2794,7 @@
 		return;
 
 	//what do we want hear CLEAR_DISPLAY_MESSAGE or CLEAR_PROMPT_STATUS???
-	//if we are clearing the display, it appears there is no instance and refernece info (size 0)
+	//if we are clearing the display, it appears there is no instance and reference info (size 0)
 	//req->data.clearpromptstatus.lineInstance = instance;
 	//req->data.clearpromptstatus.callReference = reference;
 
@@ -3144,7 +3144,7 @@
 	else
 		req->data.forwardstat.activeforward = htolel(0);
 
-	SKINNY_DEBUG(DEBUG_PACKET, 3, "Transmitting FORWARD_STAT_MESSAGE to %s, inst %d, all %s, busy %s, noans %s, acitve %d\n",
+	SKINNY_DEBUG(DEBUG_PACKET, 3, "Transmitting FORWARD_STAT_MESSAGE to %s, inst %d, all %s, busy %s, noans %s, active %d\n",
 		d->name, l->instance, l->call_forward_all, l->call_forward_busy, l->call_forward_noanswer, anyon ? 7 : 0);
 	transmit_response(d, req);
 }
@@ -3576,7 +3576,7 @@
 		transmit_lamp_indication(d, STIMULUS_VOICEMAIL, l->instance, SKINNY_LAMP_OFF);
 	}
 
-	/* find out wether the device lamp should be on or off */
+	/* find out whether the device lamp should be on or off */
 	AST_LIST_TRAVERSE(&d->lines, l2, list) {
 		if (l2->newmsgs) {
 			dev_msgs++;
diff --git a/channels/chan_unistim.c b/channels/chan_unistim.c
index 99cd2d1..0240509 100644
--- a/channels/chan_unistim.c
+++ b/channels/chan_unistim.c
@@ -465,7 +465,7 @@
 	unsigned short last_seq_ack;    /*!< sequence number of the last ACK received */
 	unsigned long tick_next_ping;   /*!< time for the next ping */
 	int last_buf_available;	 /*!< number of a free slot */
-	int nb_retransmit;		      /*!< number of retransmition */
+	int nb_retransmit;		      /*!< number of retransmission */
 	int state;				      /*!< state of the phone (see phone_state) */
 	int size_buff_entry;	    /*!< size of the buffer used to enter datas */
 	char buff_entry[16];	    /*!< Buffer for temporary datas */
@@ -684,10 +684,10 @@
 /* ISO-8859-4 - Baltic) */
 static const unsigned char packet_send_charset_iso_8859_4[] =
 	{ 0x17, 0x08, 0x21, 0x1b, 0x2d, 0x44, 0x1b, 0x00 };
-/* ISO 8859-5 - cyrilic */
+/* ISO 8859-5 - cyrillic */
 static const unsigned char packet_send_charset_iso_8859_5[] =
 	{ 0x17, 0x08, 0x21, 0x1b, 0x2d, 0x4c, 0x1b, 0x00 };
-/* Japaneese (ISO-2022-JP ?) */
+/* Japanese (ISO-2022-JP ?) */
 static const unsigned char packet_send_charset_iso_2022_jp[] =
 	{ 0x17, 0x08, 0x21, 0x1b, 0x29, 0x49, 0x1b, 0x7e };
 
@@ -3118,7 +3118,7 @@
 
 	sub = get_sub(s->device, SUB_THREEWAY);
 	if (sub) {
-		/* If sub for threway call created than we use transfer behaviuor */
+		/* If sub for threway call created than we use transfer behavior */
 		struct unistim_subchannel *sub_trans = NULL;
 		struct unistim_device *d = s->device;
 
diff --git a/channels/console_gui.c b/channels/console_gui.c
index 312da39..955c81e 100644
--- a/channels/console_gui.c
+++ b/channels/console_gui.c
@@ -54,12 +54,12 @@
   enable/disable Picture-in-Picture, freeze the incoming video,
   dial numbers, pick up or hang up a call, ...)
 
-Configuration options control the appeareance of the gui:
+Configuration options control the appearance of the gui:
 
     keypad = /tmp/kpad2.jpg	; the skin
     keypad_font = /tmp/font.png	; the font to use for output
 
-For future implementation, intresting features can be the following:
+For future implementation, interesting features can be the following:
 - save of the whole SDL window as a picture
 - audio output device switching
 
@@ -231,7 +231,7 @@
  * below the source windows
  */
 
-/* costants defined to describe status of devices */
+/* constants defined to describe status of devices */
 #define IS_PRIMARY 1
 #define IS_SECONDARY 2
 #define IS_ON 4
@@ -781,13 +781,13 @@
 			  button.x < x0+gui->keypad->w/2+BORDER+pip_loc_x+env->loc_dpy.w/3 &&
 			  button.y >= BORDER+pip_loc_y &&
 			  button.y < BORDER+pip_loc_y+env->loc_dpy.h/3) {
-				/* set the y cordinate to his previous value */
+				/* set the y coordinate to his previous value */
 				button.y += (env->out.device_num ? SRC_WIN_H+2*BORDER+SRC_MSG_BD_H : 0);
 				/* starts dragging the picture inside the picture */
 				set_drag(&gui->drag, button.x, button.y, DRAG_PIP);
 			}
 			else if (index == KEY_LOC_DPY) {
-				/* set the y cordinate to his previous value */
+				/* set the y coordinate to his previous value */
 				button.y += (env->out.device_num ? SRC_WIN_H+2*BORDER+SRC_MSG_BD_H : 0);
 				/* click in the local display, but not on the PiP */
 				set_drag(&gui->drag, button.x, button.y, DRAG_LOCAL);
@@ -1057,7 +1057,7 @@
 
 static void keypad_setup(struct gui_info *gui, const char *kp_file);
 
-/* TODO: consistency checks, check for bpp, widht and height */
+/* TODO: consistency checks, check for bpp, width and height */
 /* Init the mask image used to grab the action. */
 static struct gui_info *gui_init(const char *keypad_file, const char *font)
 {
diff --git a/channels/console_video.c b/channels/console_video.c
index 4bf2918..1975f06 100644
--- a/channels/console_video.c
+++ b/channels/console_video.c
@@ -112,7 +112,7 @@
 /*
  * Codecs are absolutely necessary or we cannot do anything.
  * SDL is optional (used for rendering only), so that we can still
- * stream video withouth displaying it.
+ * stream video without displaying it.
  */
 #if !defined(HAVE_VIDEO_CONSOLE) || !defined(HAVE_FFMPEG)
 /* stubs if required pieces are missing */
@@ -162,7 +162,7 @@
 
 /*
  * this structure will be an entry in the table containing
- * every device specified in the file oss.conf, it contains various infomation
+ * every device specified in the file oss.conf, it contains various information
  * about the device
  */
 struct video_device {
@@ -173,7 +173,7 @@
 	struct fbuf_t		*dev_buf;	/* buffer for incoming data		*/
 	struct timeval		last_frame;	/* when we read the last frame ?	*/
 	int 			status_index;	/* what is the status of the device (source) */
-	/* status index is set using the IS_ON, IS_PRIMARY and IS_SECONDARY costants */
+	/* status index is set using the IS_ON, IS_PRIMARY and IS_SECONDARY constants */
 	/* status_index is the index of the status message in the src_msgs array in console_gui.c */
 };
 
@@ -779,7 +779,7 @@
  * is returned as an argument.
  *
  * \param env = video environment descriptor
- * \param tail = tail ponter (pratically a return value)
+ * \param tail = tail ponter (practically a return value)
  */
 static struct ast_frame *get_video_frames(struct video_desc *env, struct ast_frame **tail)
 {
@@ -794,7 +794,7 @@
 	updating the private device buffer in the device table */
 	for (i = 0; i < env->out.device_num; i++) {
 		p_read = grabber_read(&env->out.devices[i], env->out.fps);
-		/* it is used only if different from NULL, we mantain last good buffer otherwise */
+		/* it is used only if different from NULL, we maintain last good buffer otherwise */
 		if (p_read)
 			env->out.devices[i].dev_buf = p_read;
 	}
diff --git a/channels/dahdi/bridge_native_dahdi.c b/channels/dahdi/bridge_native_dahdi.c
index 3302188..46fc726 100644
--- a/channels/dahdi/bridge_native_dahdi.c
+++ b/channels/dahdi/bridge_native_dahdi.c
@@ -278,7 +278,7 @@
 #if defined(HAVE_PRI)
 		/*
 		 * PRI nobch channels (hold and call waiting) are equivalent to
-		 * pseudo channels and cannot be nativly bridged.
+		 * pseudo channels and cannot be natively bridged.
 		 */
 		|| (dahdi_sig_pri_lib_handles(p0->sig)
 			&& ((struct sig_pri_chan *) p0->sig_pvt)->no_b_channel)
diff --git a/channels/iax2/include/astobj.h b/channels/iax2/include/astobj.h
index e9f0071..fa55a08 100644
--- a/channels/iax2/include/astobj.h
+++ b/channels/iax2/include/astobj.h
@@ -150,7 +150,7 @@
  *
  * <b>Sample Usage:</b>
  * \code
- * struct sample_struct_componets {
+ * struct sample_struct_components {
  *    ASTOBJ_COMPONENTS_NOLOCK(struct sample_struct);
  * };
  * \endcode
diff --git a/channels/iax2/include/firmware.h b/channels/iax2/include/firmware.h
index f8063b7..a211c5d 100644
--- a/channels/iax2/include/firmware.h
+++ b/channels/iax2/include/firmware.h
@@ -62,7 +62,7 @@
 
 /*!
  * \internal
- * \brief Add firwmare related IEs to an IAX2 IE buffer.
+ * \brief Add firmware related IEs to an IAX2 IE buffer.
  *
  * \param ie_data     The IE buffer being appended to.
  * \param device_name The name of the requested firmware.
diff --git a/channels/iax2/parser.c b/channels/iax2/parser.c
index 8a36f17..571a677 100644
--- a/channels/iax2/parser.c
+++ b/channels/iax2/parser.c
@@ -302,14 +302,14 @@
 	{ IAX_IE_TRANSFERID, "TRANSFER ID", dump_int },
 	{ IAX_IE_RDNIS, "REFERRING DNIS", dump_string },
 	{ IAX_IE_PROVISIONING, "PROVISIONING", dump_prov },
-	{ IAX_IE_AESPROVISIONING, "AES PROVISIONG" },
+	{ IAX_IE_AESPROVISIONING, "AES PROVISIONING" },
 	{ IAX_IE_DATETIME, "DATE TIME", dump_datetime },
 	{ IAX_IE_DEVICETYPE, "DEVICE TYPE", dump_string },
 	{ IAX_IE_SERVICEIDENT, "SERVICE IDENT", dump_string },
 	{ IAX_IE_FIRMWAREVER, "FIRMWARE VER", dump_short },
 	{ IAX_IE_FWBLOCKDESC, "FW BLOCK DESC", dump_int },
 	{ IAX_IE_FWBLOCKDATA, "FW BLOCK DATA" },
-	{ IAX_IE_PROVVER, "PROVISIONG VER", dump_int },
+	{ IAX_IE_PROVVER, "PROVISIONING VER", dump_int },
 	{ IAX_IE_CALLINGPRES, "CALLING PRESNTN", dump_byte },
 	{ IAX_IE_CALLINGTON, "CALLING TYPEOFNUM", dump_byte },
 	{ IAX_IE_CALLINGTNS, "CALLING TRANSITNET", dump_short },
@@ -553,7 +553,7 @@
 		cmd = "QUELCH ";
 		break;
 	case IAX_COMMAND_UNQUELCH:
-		cmd = "UNQULCH";
+		cmd = "UNQUELCH";
 		break;
 	case IAX_COMMAND_POKE:
 		cmd = "POKE   ";
diff --git a/channels/sig_analog.c b/channels/sig_analog.c
index 1af56e7..33c2699 100644
--- a/channels/sig_analog.c
+++ b/channels/sig_analog.c
@@ -1288,7 +1288,7 @@
 				ast_debug(1, "Normal call hung up with both three way call and a call waiting call in place?\n");
 				if (p->subs[ANALOG_SUB_CALLWAIT].inthreeway) {
 					/* We had flipped over to answer a callwait and now it's gone */
-					ast_debug(1, "We were flipped over to the callwait, moving back and unowning.\n");
+					ast_debug(1, "We were flipped over to the callwait, moving back and not owning.\n");
 					/* Move to the call-wait, but un-own us until they flip back. */
 					analog_swap_subs(p, ANALOG_SUB_CALLWAIT, ANALOG_SUB_REAL);
 					analog_unalloc_sub(p, ANALOG_SUB_CALLWAIT);
diff --git a/channels/sig_pri.c b/channels/sig_pri.c
index 4bd5a51..f576660 100644
--- a/channels/sig_pri.c
+++ b/channels/sig_pri.c
@@ -1613,7 +1613,7 @@
 	int x;
 
 	if (principle < 0 || pri->numchans <= principle) {
-		/* Out of rannge */
+		/* Out of range */
 		return -1;
 	}
 	if (!call) {
@@ -2108,7 +2108,7 @@
 		}
 		ast_frfree(f);
 	}
-	/* Hangup the channel since nothing happend */
+	/* Hangup the channel since nothing happened */
 	ast_hangup(chan);
 	return NULL;
 }
@@ -6485,7 +6485,7 @@
 					pri_find_dchan(pri);
 				}
 
-				/* Note presense of D-channel */
+				/* Note presence of D-channel */
 				time(&pri->lastreset);
 
 				/* Restart in 5 seconds */
@@ -8604,7 +8604,7 @@
 					}
 					/*
 					 * If hangup was delayed for this AOC-E msg, waiting_for_aoc
-					 * will be set.  A hangup is already occuring via a timeout during
+					 * will be set.  A hangup is already occurring via a timeout during
 					 * this delay.  Instead of waiting for that timeout to occur, go ahead
 					 * and initiate the hangup since the delay is no longer necessary.
 					 */
diff --git a/channels/sig_pri.h b/channels/sig_pri.h
index 497e834..2486772 100644
--- a/channels/sig_pri.h
+++ b/channels/sig_pri.h
@@ -282,7 +282,7 @@
 	unsigned int hidecallerid:1;
 	unsigned int hidecalleridname:1;      /*!< Hide just the name not the number for legacy PBX use */
 	unsigned int immediate:1;			/*!< Answer before getting digits? */
-	unsigned int priexclusive:1;			/*!< Whether or not to override and use exculsive mode for channel selection */
+	unsigned int priexclusive:1;			/*!< Whether or not to override and use exclusive mode for channel selection */
 	unsigned int priindication_oob:1;
 	unsigned int use_callerid:1;			/*!< Whether or not to use caller id on this channel */
 	unsigned int use_callingpres:1;			/*!< Whether to use the callingpres the calling switch sends */
@@ -574,7 +574,7 @@
 		unsigned int hidecallerid:1;
 		unsigned int hidecalleridname:1;      /*!< Hide just the name not the number for legacy PBX use */
 		unsigned int immediate:1;			/*!< Answer before getting digits? */
-		unsigned int priexclusive:1;			/*!< Whether or not to override and use exculsive mode for channel selection */
+		unsigned int priexclusive:1;			/*!< Whether or not to override and use exclusive mode for channel selection */
 		unsigned int priindication_oob:1;
 		unsigned int use_callerid:1;			/*!< Whether or not to use caller id on this channel */
 		unsigned int use_callingpres:1;			/*!< Whether to use the callingpres the calling switch sends */
diff --git a/channels/sig_ss7.c b/channels/sig_ss7.c
index 98530da..99a5d94 100644
--- a/channels/sig_ss7.c
+++ b/channels/sig_ss7.c
@@ -2067,7 +2067,7 @@
 					break;
 				}
 				p = linkset->pvts[chanpos];
-				ast_debug(1, "Unequiped Circuit Id Code on CIC %d\n", e->ucic.cic);
+				ast_debug(1, "Unequipped Circuit Id Code on CIC %d\n", e->ucic.cic);
 				sig_ss7_lock_private(p);
 				sig_ss7_lock_owner(linkset, chanpos);
 				if (p->owner) {
diff --git a/channels/sig_ss7.h b/channels/sig_ss7.h
index e2bc8e4..5d2c04d 100644
--- a/channels/sig_ss7.h
+++ b/channels/sig_ss7.h
@@ -91,7 +91,7 @@
 	SIG_SS7_ALAW
 };
 
-enum sig_ss7_redirect_idication {
+enum sig_ss7_redirect_indication {
 	SS7_INDICATION_NO_REDIRECTION = 0,
 	SS7_INDICATION_REROUTED_PRES_ALLOWED,
 	SS7_INDICATION_REROUTED_INFO_RESTRICTED,
diff --git a/channels/sip/include/config_parser.h b/channels/sip/include/config_parser.h
index 811f895..41d1cc6 100644
--- a/channels/sip/include/config_parser.h
+++ b/channels/sip/include/config_parser.h
@@ -50,7 +50,7 @@
  * \param flags An array of ast_flags that will be set by this function
  *
  * \note The nat-related values in both mask and flags are assumed to empty. This function
- * will treat the first "yes" or "no" value in a list of values as overiding all other values
+ * will treat the first "yes" or "no" value in a list of values as overriding all other values
  * and will stop parsing. Auto values will override their non-auto counterparts.
  */
 void sip_parse_nat_option(const char *value, struct ast_flags *mask, struct ast_flags *flags);
diff --git a/channels/sip/include/reqresp_parser.h b/channels/sip/include/reqresp_parser.h
index 338824a..a0634f6 100644
--- a/channels/sip/include/reqresp_parser.h
+++ b/channels/sip/include/reqresp_parser.h
@@ -143,7 +143,7 @@
 int parse_name_andor_addr(char *uri, const char *scheme, char **name,
 			  char **user, char **pass, char **domain,
 			  struct uriparams *params, char **headers,
-			  char **remander);
+			  char **residue);
 
 /*! \brief Parse all contact header contacts
  * \retval 0 success
diff --git a/channels/sip/include/sip.h b/channels/sip/include/sip.h
index 18db352..f5b7831 100644
--- a/channels/sip/include/sip.h
+++ b/channels/sip/include/sip.h
@@ -444,7 +444,7 @@
 };
 
 /*! \brief When sending a SIP message, we can send with a few options, depending on
- * type of SIP request. UNRELIABLE is moslty used for responses to repeated requests,
+ * type of SIP request. UNRELIABLE is mostly used for responses to repeated requests,
  * where the original response would be sent RELIABLE in an INVITE transaction
  */
 enum xmittype {
@@ -1100,7 +1100,7 @@
 	int t38_maxdatagram;              /*!< T.38 FaxMaxDatagram override */
 	int request_queue_sched_id;       /*!< Scheduler ID of any scheduled action to process queued requests */
 	int provisional_keepalive_sched_id;   /*!< Scheduler ID for provisional responses that need to be sent out to avoid cancellation */
-	const char *last_provisional;         /*!< The last successfully transmitted provisonal response message */
+	const char *last_provisional;         /*!< The last successfully transmitted provisional response message */
 	int authtries;                        /*!< Times we've tried to authenticate */
 	struct sip_proxy *outboundproxy;      /*!< Outbound proxy for this dialog. Use ref_proxy to set this instead of setting it directly*/
 	struct t38properties t38;             /*!< T38 settings */
diff --git a/channels/sip/reqresp_parser.c b/channels/sip/reqresp_parser.c
index b43bed6..37602d6 100644
--- a/channels/sip/reqresp_parser.c
+++ b/channels/sip/reqresp_parser.c
@@ -728,7 +728,7 @@
 	/* clear any empty characters in the beginning */
 	input = ast_skip_blanks(input);
 
-	/* make sure the output buffer is initilized */
+	/* make sure the output buffer is initialized */
 	*orig_output = '\0';
 
 	/* make room for '\0' at the end of the output buffer */
diff --git a/channels/vcodecs.c b/channels/vcodecs.c
index e55c5fe..d887c6d 100644
--- a/channels/vcodecs.c
+++ b/channels/vcodecs.c
@@ -416,7 +416,7 @@
 	return first;
 }
 
-/*! \brief extract the bitstreem from the RTP payload.
+/*! \brief extract the bitstream from the RTP payload.
  * This is format dependent.
  * For h263+, the format is defined in RFC 2429
  * and basically has a fixed 2-byte header as follows:

diff --git a/channels/chan_dahdi.c b/channels/chan_dahdi.c
index 74c76f7..8480775 100644
--- a/channels/chan_dahdi.c
+++ b/channels/chan_dahdi.c
@@ -226,7 +226,7 @@
 				canceller on the channel (if any), for the current call
 				only.</para>
 				<para>Possible values are:</para>
-				<para>	<literal>on</literal>	Normal mode (the echo canceller is actually reinitalized)</para>
+				<para>	<literal>on</literal>	Normal mode (the echo canceller is actually reinitialized)</para>
 				<para>	<literal>off</literal>	Disabled</para>
 				<para>	<literal>fax</literal>	FAX/data mode (NLP disabled if possible, otherwise
 					completely disabled)</para>
@@ -2897,13 +2897,13 @@
  *
  * \details
  * original dialstring:
- * DAHDI/[i<span>-](g|G|r|R)<group#(0-63)>[c|r<cadance#>|d][/extension[/options]]
+ * DAHDI/[i<span>-](g|G|r|R)<group#(0-63)>[c|r<cadence#>|d][/extension[/options]]
  *
  * The modified dialstring will have prefixed the channel-group section
  * with the ISDN channel restriction.
  *
  * buf:
- * DAHDI/i<span>-(g|G|r|R)<group#(0-63)>[c|r<cadance#>|d][/extension[/options]]
+ * DAHDI/i<span>-(g|G|r|R)<group#(0-63)>[c|r<cadence#>|d][/extension[/options]]
  *
  * The routine will check to see if the ISDN channel restriction is already
  * in the original dialstring.
@@ -3170,7 +3170,7 @@
  *
  * \param pvt Private channel structure.
  * \param state Initial state of new channel.
- * \param law Combanding law to use.
+ * \param law Companding law to use.
  * \param exten Dialplan extension for incoming call.
  * \param requestor Channel requesting this new channel.
  *
@@ -4407,7 +4407,7 @@
 	case SIG_FEATDMF:
 		return "Feature Group D (MF)";
 	case SIG_FEATDMF_TA:
-		return "Feature Groud D (MF) Tandem Access";
+		return "Feature Group D (MF) Tandem Access";
 	case SIG_FEATB:
 		return "Feature Group B (MF)";
 	case SIG_E911:
@@ -6188,7 +6188,7 @@
 				ast_debug(1, "Normal call hung up with both three way call and a call waiting call in place?\n");
 				if (p->subs[SUB_CALLWAIT].inthreeway) {
 					/* We had flipped over to answer a callwait and now it's gone */
-					ast_debug(1, "We were flipped over to the callwait, moving back and unowning.\n");
+					ast_debug(1, "We were flipped over to the callwait, moving back and not owning.\n");
 					/* Move to the call-wait, but un-own us until they flip back. */
 					swap_subs(p, SUB_CALLWAIT, SUB_REAL);
 					unalloc_sub(p, SUB_CALLWAIT);
@@ -13328,8 +13328,8 @@
 	int rr_starting_point;
 	/*! ISDN span where channels can be picked (Zero if not specified) */
 	int span;
-	/*! Analog channel distinctive ring cadance index. */
-	int cadance;
+	/*! Analog channel distinctive ring cadence index. */
+	int cadence;
 	/*! Dialing option. c/r/d if present and valid. */
 	char opt;
 	/*! TRUE if to search the channel list backwards. */
@@ -13355,10 +13355,10 @@
 	/*
 	 * data is ---v
 	 * Dial(DAHDI/pseudo[/extension[/options]])
-	 * Dial(DAHDI/<channel#>[c|r<cadance#>|d][/extension[/options]])
-	 * Dial(DAHDI/<subdir>!<channel#>[c|r<cadance#>|d][/extension[/options]])
+	 * Dial(DAHDI/<channel#>[c|r<cadence#>|d][/extension[/options]])
+	 * Dial(DAHDI/<subdir>!<channel#>[c|r<cadence#>|d][/extension[/options]])
 	 * Dial(DAHDI/i<span>[/extension[/options]])
-	 * Dial(DAHDI/[i<span>-](g|G|r|R)<group#(0-63)>[c|r<cadance#>|d][/extension[/options]])
+	 * Dial(DAHDI/[i<span>-](g|G|r|R)<group#(0-63)>[c|r<cadence#>|d][/extension[/options]])
 	 *
 	 * i - ISDN span channel restriction.
 	 *     Used by CC to ensure that the CC recall goes out the same span.
@@ -13371,7 +13371,7 @@
 	 * R - channel group allocation round robin search backward
 	 *
 	 * c - Wait for DTMF digit to confirm answer
 	 * r<cadance#> - Set distintive ring cadance number
 	 * d - Force bearer capability for ISDN/SS7 call to digital.
 	 */
 
@@ -13421,7 +13421,7 @@
 	if (toupper(args.group[0]) == 'G' || toupper(args.group[0])=='R') {
 		/* Retrieve the group number */
 		s = args.group + 1;
-		res = sscanf(s, "%30d%1c%30d", &x, &param->opt, &param->cadance);
+		res = sscanf(s, "%30d%1c%30d", &x, &param->opt, &param->cadence);
 		if (res < 1) {
 			ast_log(LOG_WARNING, "Unable to determine group for data %s\n", data);
 			return NULL;
@@ -13460,7 +13460,7 @@
 			x = CHAN_PSEUDO;
 			param->channelmatch = x;
 		} else {
-			res = sscanf(s, "%30d%1c%30d", &x, &param->opt, &param->cadance);
+			res = sscanf(s, "%30d%1c%30d", &x, &param->opt, &param->cadence);
 			if (res < 1) {
 				ast_log(LOG_WARNING, "Unable to determine channel for data %s\n", data);
 				return NULL;
@@ -13566,7 +13566,7 @@
 				break;
 			case 'r':
 				/* Distinctive ring */
-				p->distinctivering = start.cadance;
+				p->distinctivering = start.cadence;
 				break;
 			case 'd':
 #if defined(HAVE_PRI) || defined(HAVE_SS7)
@@ -17700,7 +17700,7 @@
 			return -1;
 		}
 		if (finish < start) {
-			ast_log(LOG_WARNING, "Sillyness: %d < %d\n", start, finish);
+			ast_log(LOG_WARNING, "Silliness: %d < %d\n", start, finish);
 			x = finish;
 			finish = start;
 			start = x;
@@ -13371,7 +13371,7 @@
 	 *
 	 * c - Wait for DTMF digit to confirm answer
-	 * r<cadance#> - Set distintive ring cadance number
+	 * r<cadence#> - Set distinctive ring cadence number
 	 * d - Force bearer capability for ISDN/SS7 call to digital.
 	 */
-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/17415
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: 19
Gerrit-Change-Id: Ife52ee89cd2170b684fa651ca72b1cb911a57339
Gerrit-Change-Number: 17415
Gerrit-PatchSet: 2
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-Reviewer: Friendly Automation
Gerrit-Reviewer: George Joseph <gjoseph at digium.com>
Gerrit-MessageType: merged
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211115/cd169f5e/attachment-0001.html>


More information about the asterisk-code-review mailing list